@@ -2,11 +2,11 @@ __author__ = "Swas.py"
 __title__ = "vscode"
 __license__ = "MIT"
 __copyright__ = "Copyright 2021 Swas.py"
-__version__ = "1.5.1"
+__version__ = "1.5.3"
 
 from . import window
 from .compiler import build, build_theme
-from .extension import Extension
+from .extension import *
 from .themes import ColorTheme
 from .env_methods import env
 from . import types as ext
