@@ -1,7 +1,8 @@
-import os
-import json
-import time
 import inspect
+import json
+import os
+import time
+from .utils import combine_list_dicts
 from .extension import Extension
 from .themes import ColorTheme
 
@@ -68,12 +69,17 @@ def build_py(functions):
 
 def build_js(name, events, commands, activity_bar_config=None):
     cwd = os.getcwd()
-    python_path = os.path.join(cwd, "build", "extension.py").replace("\\", "\\\\")
+    # python_path = os.path.join(cwd, "build", "extension.py").replace("\\", "\\\\")
 
     imports = ""
-    directory, filename = os.path.split(inspect.getfile(build_py))
-    with open(os.path.join(directory, "main.js"), "r") as f:
-        imports += f.read()
+    directory, _ = os.path.split(inspect.getfile(build_py))
+    try:
+        with open(os.path.join(directory, "main.js"), "r") as f:
+            imports += f.read()
+    except FileNotFoundError:
+        with open(os.path.join(directory, "data.py"), "r") as f:
+            imports += f.read().replace("'''", "")
+
     on_activate = events.get("activate")
     code_on_activate = "function activate(context) {\nlet globalStorage = {}\n"
     if on_activate:
@@ -85,18 +91,18 @@ def build_js(name, events, commands, activity_bar_config=None):
             f'let html = "{html}"; let id = "{activity_bar_config["id"]}";\n'
         )
         code_on_activate += """
-let thisProvider = {
-  resolveWebviewView: function (thisWebview, thisWebviewContext, thisToken) {
-    thisWebview.webview.options = { enableScript: true };
-    thisWebview.webview.html = html;
-  },
-};
-context.subscriptions.push(
-  vscode.window.registerWebviewViewProvider(id, thisProvider)
-);
-            
-            
-"""
+        let thisProvider = {
+        resolveWebviewView: function (thisWebview, thisWebviewContext, thisToken) {
+            thisWebview.webview.options = { enableScript: true };
+            thisWebview.webview.html = html;
+        },
+        };
+        context.subscriptions.push(
+        vscode.window.registerWebviewViewProvider(id, thisProvider)
+        );
+                    
+                    
+        """
     for command in commands:
         code_on_activate += (
             f"let {command.name} = vscode.commands.registerCommand('{command.extension(name)}',"
@@ -107,15 +113,15 @@ context.subscriptions.push(
             f'let funcName = "{command.func_name}"; let pyVar = "{pyvar}";'
         )
         code_on_activate += """
-let py = spawn(pyVar, [pythonPath, funcName]);
+        let py = spawn(pyVar, [pythonPath, funcName]);
 
-py.stdout.on("data", (data) => {
-    executeCommands(py, data, globalStorage);
-});
-py.stderr.on("data", (data) => {
-    console.error(`An Error occurred in the python script: ${data}`);
-});
-"""
+        py.stdout.on("data", (data) => {
+            executeCommands(py, data, globalStorage);
+        });
+        py.stderr.on("data", (data) => {
+            console.error(`An Error occurred in the python script: ${data}`);
+        });
+        """
         code_on_activate += "});\n"
         code_on_activate += f"context.subscriptions.push({command.name});\n"
 
@@ -129,8 +135,7 @@ py.stderr.on("data", (data) => {
     code_on_deactivate += "}"
     main = code_on_activate + "\n" + code_on_deactivate
     exports = "module.exports = {activate,deactivate}"
-    code = f"{imports}\n{main}\n\n{exports}"
-    return code
+    return f"{imports}\n{main}\n\n{exports}"
 
 
 def create_files(package, javascript, python, publish):
@@ -193,6 +198,11 @@ def create_files(package, javascript, python, publish):
 def build(extension: Extension, publish: bool = False, config: dict = None) -> None:
     """
     Builds the extension.
+
+    Parameters:
+    - extension: The extension to build
+    - publish: If `True`, files needed for publishing will be created
+    - config: Configuration data
     """
     if config is None:
         config = {}
@@ -218,11 +228,25 @@ def build(extension: Extension, publish: bool = False, config: dict = None) -> N
         commands.append(cmd)
         activation_events.append(event)
 
+    main_config = []
+    for contrib_config in extension.config:
+        contrib_config.name = f"{extension.name}.{contrib_config.name}"
+        contrib_dict = contrib_config.__dict__
+        del contrib_dict["name"]
+        contrib_dict = {contrib_config.name: contrib_dict}
+        main_config.append(contrib_dict)
+
     package_config = config
     package_config.update(
         {
             "contributes": {
                 "commands": commands,
+                "configuration": {
+                    "title": extension.display_name,
+                    "properties": combine_list_dicts(main_config)
+                    if len(main_config)
+                    else {},
+                },
             },
             "activationEvents": activation_events,
         }
