@@ -28,9 +28,7 @@ def show_quick_pick(items: list, options: QuickPickOptions = None) -> QuickPickI
     elif isinstance(res, dict):
         return QuickPickItem(**res)
     else:
-        data = []
-        for r in res:
-            data.append(QuickPickItem(**r) if isinstance(r, dict) else r)
+        data = [QuickPickItem(**r) if isinstance(r, dict) else r for r in res]
         return data
 
 
@@ -50,8 +48,7 @@ def show_input_box(options: InputBoxOptions = None) -> str:
 
 def _base(func: str, text: str, *args: str) -> str:
     send_ipc("SM", [func, text, *args])
-    res = json_input()
-    return res
+    return json_input()
 
 
 def show_info_message(text: str, *args: str) -> str:
@@ -90,6 +87,7 @@ def set_status_bar_message(text: str, hide_after_timeout: int = None) -> Disposa
     res = json_input()
     return Disposable(res)
 
+
 def show_open_dialog(options: OpenDialogOptions = None) -> list:
     if isinstance(options, OpenDialogOptions):
         options = options.__dict__
@@ -108,25 +106,24 @@ def show_save_dialog(options: SaveDialogOptions = None) -> dict:
     send_ipc("SM", ["showSaveDialog", options])
     return json_input()
 
-class ActiveTextEditor:
-    """
-    The currently active editor or undefined. The active editor is the one that currently has focus or, when none has focus, the one that has changed input most recently.
-    """
+class TextEditor:
 
-    def __init__(self):
-        send_ipc("AT", [])
-        res = json_input()
-        if not res:
-            self = undefined
+    def __init__(self, data: dict = None):
+        if not data:
+            send_ipc("AT", [])
+            res = json_input()
+            if not res:
+                self = undefined
+        else:
+            res = data
         self.__dict__.update(apply_func_to_keys(res, camel_to_snake))
         self.document = TextDocument(self.document)
         if hasattr(self, "selections"):
-            data = []
-            for sel in self.selections:
-                data.append(Selection.from_dict(sel))
+            data = [Selection.from_dict(sel) for sel in self.selections]
             self.selections = data
             self.selection = data[0]
 
+
     @property
     def cursor(self) -> Position:
         """
@@ -158,3 +155,17 @@ class ActiveTextEditor:
         """
 
         return self.replace(Range(location, location), value)
+
+class ActiveTextEditor(TextEditor):
+    """
+    The currently active editor or undefined. The active editor is the one that currently has focus or, when none has focus, the one that has changed input most recently.
+    """
+    pass
+
+def show_text_document(uri: str, options: Optional[TextDocumentShowOptions] = None) -> TextEditor:
+    if isinstance(options, TextDocumentShowOptions):
+        options = options.__dict__
+    elif options is None:
+        options = {}
+    send_ipc("ST", [uri, options])
+    return TextEditor(json_input())
\ No newline at end of file
